# Changelog


## 0.1.15 - 2017-02-05

* Fix ImportError of pypandoc


## 0.1.14 - 2017-01-16

* Add get to retrieve whole datasets
* Add get_page to retrieve datasets one page at a time
* Add endpoints: companies, securities, indices, prices, news
